module Repositorium
  class Client
    VERSION = "0.0.1"
    attr_accessor :host, :port, :key

    def initialize(host: 'localhost', port: 1234, key: "key")
      self.host = host
      self.port = port
      self.key = key
    end

    def list_repos
      connection.get("")
    end

    def create_repo(user, repo)
      connection.post("#{user}/#{repo}")
    end

    def delete_repo(user,repo)
      connection.delete("#{user}/#{repo}")
    end  

    def list_platforms(user,repo)
      connection.get("#{user}/#{repo}")
    end

    def update_platform(user,repo, platform)
      connection.put("#{user}/#{repo}/#{platform}")
    end

    def list_files(user,repo, platform)
      connection.get("#{user}/#{repo}/#{platform}")
    end

    def create_file(user, repo, platform, file, body = "")
      connection.post("#{user}/#{repo}/#{platform}/#{file}") do |req|
        req.body = body
      end
    end

    def update_file(user, repo, platform, file, body = "")
      connection.put("#{user}/#{repo}/#{platform}/#{file}") do |req|
        req.body = body
      end
    end

    def get_file(user, repo, platform, file)
      connection.get("#{user}/#{repo}/#{platform}/#{file}")
    end

    def delete_file(user, repo, platform, file)
      connection.delete("#{user}/#{repo}/#{platform}/#{file}")
    end

    private

    def connection
      @connection ||= ::Faraday.new(
        url: "http://#{host}:#{port}", 
        ssl: {:verify => false},
        headers: {
          "Key" => key
        }
      )
    end

  end
end
